/*
 *  Copyright (c) 2021 Daniel Wilkins.
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.

 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH 
 * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, 
 * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 ****************************************************************************/

#ifndef LOGOS_H_H
#define LOGOS_H_H

#include <stdarg.h>

enum LogLevel {
    LOG_ERROR,
    LOG_WARN,
    LOG_INFO,
    LOG_DEBUG
};

FILE *log_destination;

enum LogLevel log_level;

void logos_init(FILE *destination, enum LogLevel level) {
    log_destination = destination ? destination : stderr;
    
    log_level = level;
}

void logos_log(enum LogLevel level, char *fmt, ...) {
    if (level <= log_level) {
        va_list args;
        va_start(args, fmt);

        vfprintf(log_destination, fmt, args);
        va_end(args);
        fprintf(log_destination, "\n");
    }
}

#endif /* LOGOS_H_H */
